# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_faceinfo.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_faceinfo.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x16\x63odemao_faceinfo.proto\"\x11\n\x0f\x46\x61\x63\x65InfoRequest\"h\n\x10\x46\x61\x63\x65InfoResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06gender\x18\x03 \x01(\x05\x12\x0b\n\x03\x61ge\x18\x04 \x01(\x05\x12\r\n\x05width\x18\x05 \x01(\x05\x12\x0e\n\x06height\x18\x06 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_FACEINFOREQUEST = _descriptor.Descriptor(
    name='FaceInfoRequest',
    full_name='FaceInfoRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=26,
    serialized_end=43,
)

_FACEINFORESPONSE = _descriptor.Descriptor(
    name='FaceInfoResponse',
    full_name='FaceInfoResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='id', full_name='FaceInfoResponse.id', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='name', full_name='FaceInfoResponse.name', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='gender', full_name='FaceInfoResponse.gender', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='age', full_name='FaceInfoResponse.age', index=3,
            number=4, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='width', full_name='FaceInfoResponse.width', index=4,
            number=5, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='height', full_name='FaceInfoResponse.height', index=5,
            number=6, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=45,
    serialized_end=149,
)

DESCRIPTOR.message_types_by_name['FaceInfoRequest'] = _FACEINFOREQUEST
DESCRIPTOR.message_types_by_name['FaceInfoResponse'] = _FACEINFORESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FaceInfoRequest = _reflection.GeneratedProtocolMessageType('FaceInfoRequest', (_message.Message,), {
    'DESCRIPTOR': _FACEINFOREQUEST,
    '__module__': 'codemao_faceinfo_pb2'
    # @@protoc_insertion_point(class_scope:FaceInfoRequest)
})
_sym_db.RegisterMessage(FaceInfoRequest)

FaceInfoResponse = _reflection.GeneratedProtocolMessageType('FaceInfoResponse', (_message.Message,), {
    'DESCRIPTOR': _FACEINFORESPONSE,
    '__module__': 'codemao_faceinfo_pb2'
    # @@protoc_insertion_point(class_scope:FaceInfoResponse)
})
_sym_db.RegisterMessage(FaceInfoResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
