# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_setmouthlamp.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_setmouthlamp.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x1a\x63odemao_setmouthlamp.proto\"]\n\x13SetMouthLampRequest\x12\r\n\x05model\x18\x01 \x01(\x05\x12\r\n\x05\x63olor\x18\x02 \x01(\x05\x12\x10\n\x08\x64uration\x18\x03 \x01(\x05\x12\x16\n\x0e\x62reathDuration\x18\x04 \x01(\x05\"=\n\x14SetMouthLampResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_SETMOUTHLAMPREQUEST = _descriptor.Descriptor(
    name='SetMouthLampRequest',
    full_name='SetMouthLampRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='model', full_name='SetMouthLampRequest.model', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='color', full_name='SetMouthLampRequest.color', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='duration', full_name='SetMouthLampRequest.duration', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='breathDuration', full_name='SetMouthLampRequest.breathDuration', index=3,
            number=4, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=30,
    serialized_end=123,
)

_SETMOUTHLAMPRESPONSE = _descriptor.Descriptor(
    name='SetMouthLampResponse',
    full_name='SetMouthLampResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='SetMouthLampResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='SetMouthLampResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=125,
    serialized_end=186,
)

DESCRIPTOR.message_types_by_name['SetMouthLampRequest'] = _SETMOUTHLAMPREQUEST
DESCRIPTOR.message_types_by_name['SetMouthLampResponse'] = _SETMOUTHLAMPRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SetMouthLampRequest = _reflection.GeneratedProtocolMessageType('SetMouthLampRequest', (_message.Message,), {
    'DESCRIPTOR': _SETMOUTHLAMPREQUEST,
    '__module__': 'codemao_setmouthlamp_pb2'
    # @@protoc_insertion_point(class_scope:SetMouthLampRequest)
})
_sym_db.RegisterMessage(SetMouthLampRequest)

SetMouthLampResponse = _reflection.GeneratedProtocolMessageType('SetMouthLampResponse', (_message.Message,), {
    'DESCRIPTOR': _SETMOUTHLAMPRESPONSE,
    '__module__': 'codemao_setmouthlamp_pb2'
    # @@protoc_insertion_point(class_scope:SetMouthLampResponse)
})
_sym_db.RegisterMessage(SetMouthLampResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
