# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_controlmouthlamp.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_controlmouthlamp.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x1e\x63odemao_controlmouthlamp.proto\"%\n\x13\x43ontrolMouthRequest\x12\x0e\n\x06isOpen\x18\x01 \x01(\x08\"=\n\x14\x43ontrolMouthResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_CONTROLMOUTHREQUEST = _descriptor.Descriptor(
    name='ControlMouthRequest',
    full_name='ControlMouthRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isOpen', full_name='ControlMouthRequest.isOpen', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=34,
    serialized_end=71,
)

_CONTROLMOUTHRESPONSE = _descriptor.Descriptor(
    name='ControlMouthResponse',
    full_name='ControlMouthResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='ControlMouthResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='ControlMouthResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=73,
    serialized_end=134,
)

DESCRIPTOR.message_types_by_name['ControlMouthRequest'] = _CONTROLMOUTHREQUEST
DESCRIPTOR.message_types_by_name['ControlMouthResponse'] = _CONTROLMOUTHRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ControlMouthRequest = _reflection.GeneratedProtocolMessageType('ControlMouthRequest', (_message.Message,), {
    'DESCRIPTOR': _CONTROLMOUTHREQUEST,
    '__module__': 'codemao_controlmouthlamp_pb2'
    # @@protoc_insertion_point(class_scope:ControlMouthRequest)
})
_sym_db.RegisterMessage(ControlMouthRequest)

ControlMouthResponse = _reflection.GeneratedProtocolMessageType('ControlMouthResponse', (_message.Message,), {
    'DESCRIPTOR': _CONTROLMOUTHRESPONSE,
    '__module__': 'codemao_controlmouthlamp_pb2'
    # @@protoc_insertion_point(class_scope:ControlMouthResponse)
})
_sym_db.RegisterMessage(ControlMouthResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
