# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_expressioninfo.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_expressioninfo.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x1c\x63odemao_expressioninfo.proto\"\x17\n\x15\x45xpressionInfoRequest\"@\n\x16\x45xpressionInfoResponse\x12\x11\n\texpressId\x18\x01 \x01(\x05\x12\x13\n\x0b\x65xpressName\x18\x02 \x01(\tB\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_EXPRESSIONINFOREQUEST = _descriptor.Descriptor(
    name='ExpressionInfoRequest',
    full_name='ExpressionInfoRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=32,
    serialized_end=55,
)

_EXPRESSIONINFORESPONSE = _descriptor.Descriptor(
    name='ExpressionInfoResponse',
    full_name='ExpressionInfoResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='expressId', full_name='ExpressionInfoResponse.expressId', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='expressName', full_name='ExpressionInfoResponse.expressName', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=57,
    serialized_end=121,
)

DESCRIPTOR.message_types_by_name['ExpressionInfoRequest'] = _EXPRESSIONINFOREQUEST
DESCRIPTOR.message_types_by_name['ExpressionInfoResponse'] = _EXPRESSIONINFORESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExpressionInfoRequest = _reflection.GeneratedProtocolMessageType('ExpressionInfoRequest', (_message.Message,), {
    'DESCRIPTOR': _EXPRESSIONINFOREQUEST,
    '__module__': 'codemao_expressioninfo_pb2'
    # @@protoc_insertion_point(class_scope:ExpressionInfoRequest)
})
_sym_db.RegisterMessage(ExpressionInfoRequest)

ExpressionInfoResponse = _reflection.GeneratedProtocolMessageType('ExpressionInfoResponse', (_message.Message,), {
    'DESCRIPTOR': _EXPRESSIONINFORESPONSE,
    '__module__': 'codemao_expressioninfo_pb2'
    # @@protoc_insertion_point(class_scope:ExpressionInfoResponse)
})
_sym_db.RegisterMessage(ExpressionInfoResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
