# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_controlregisterface.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_controlregisterface.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n!codemao_controlregisterface.proto\"L\n\x1a\x43ontrolRegisterFaceRequest\x12\x0e\n\x06userId\x18\x01 \x01(\x05\x12\x10\n\x08userName\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\x05\"Z\n\x1b\x43ontrolRegisterFaceResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x12\x14\n\x0cregisterName\x18\x03 \x01(\tB\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_CONTROLREGISTERFACEREQUEST = _descriptor.Descriptor(
    name='ControlRegisterFaceRequest',
    full_name='ControlRegisterFaceRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='userId', full_name='ControlRegisterFaceRequest.userId', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='userName', full_name='ControlRegisterFaceRequest.userName', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='type', full_name='ControlRegisterFaceRequest.type', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=37,
    serialized_end=113,
)

_CONTROLREGISTERFACERESPONSE = _descriptor.Descriptor(
    name='ControlRegisterFaceResponse',
    full_name='ControlRegisterFaceResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='ControlRegisterFaceResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='ControlRegisterFaceResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='registerName', full_name='ControlRegisterFaceResponse.registerName', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=115,
    serialized_end=205,
)

DESCRIPTOR.message_types_by_name['ControlRegisterFaceRequest'] = _CONTROLREGISTERFACEREQUEST
DESCRIPTOR.message_types_by_name['ControlRegisterFaceResponse'] = _CONTROLREGISTERFACERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ControlRegisterFaceRequest = _reflection.GeneratedProtocolMessageType('ControlRegisterFaceRequest', (_message.Message,),
                                                                      {
                                                                          'DESCRIPTOR': _CONTROLREGISTERFACEREQUEST,
                                                                          '__module__': 'codemao_controlregisterface_pb2'
                                                                          # @@protoc_insertion_point(class_scope:ControlRegisterFaceRequest)
                                                                      })
_sym_db.RegisterMessage(ControlRegisterFaceRequest)

ControlRegisterFaceResponse = _reflection.GeneratedProtocolMessageType('ControlRegisterFaceResponse',
                                                                       (_message.Message,), {
                                                                           'DESCRIPTOR': _CONTROLREGISTERFACERESPONSE,
                                                                           '__module__': 'codemao_controlregisterface_pb2'
                                                                           # @@protoc_insertion_point(class_scope:ControlRegisterFaceResponse)
                                                                       })
_sym_db.RegisterMessage(ControlRegisterFaceResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
