# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_getregisterfaces.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from ..pb2 import codemao_faceinfo_pb2 as codemao__faceinfo__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_getregisterfaces.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x1e\x63odemao_getregisterfaces.proto\x1a\x16\x63odemao_faceinfo.proto\"\x19\n\x17GetRegisterFacesRequest\"g\n\x18GetRegisterFacesResponse\x12$\n\tfaceInfos\x18\x01 \x03(\x0b\x32\x11.FaceInfoResponse\x12\x11\n\tisSuccess\x18\x02 \x01(\x08\x12\x12\n\nresultCode\x18\x03 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
    ,
    dependencies=[codemao__faceinfo__pb2.DESCRIPTOR, ])

_GETREGISTERFACESREQUEST = _descriptor.Descriptor(
    name='GetRegisterFacesRequest',
    full_name='GetRegisterFacesRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=58,
    serialized_end=83,
)

_GETREGISTERFACESRESPONSE = _descriptor.Descriptor(
    name='GetRegisterFacesResponse',
    full_name='GetRegisterFacesResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='faceInfos', full_name='GetRegisterFacesResponse.faceInfos', index=0,
            number=1, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='GetRegisterFacesResponse.isSuccess', index=1,
            number=2, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='GetRegisterFacesResponse.resultCode', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=85,
    serialized_end=188,
)

_GETREGISTERFACESRESPONSE.fields_by_name['faceInfos'].message_type = codemao__faceinfo__pb2._FACEINFORESPONSE
DESCRIPTOR.message_types_by_name['GetRegisterFacesRequest'] = _GETREGISTERFACESREQUEST
DESCRIPTOR.message_types_by_name['GetRegisterFacesResponse'] = _GETREGISTERFACESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetRegisterFacesRequest = _reflection.GeneratedProtocolMessageType('GetRegisterFacesRequest', (_message.Message,), {
    'DESCRIPTOR': _GETREGISTERFACESREQUEST,
    '__module__': 'codemao_getregisterfaces_pb2'
    # @@protoc_insertion_point(class_scope:GetRegisterFacesRequest)
})
_sym_db.RegisterMessage(GetRegisterFacesRequest)

GetRegisterFacesResponse = _reflection.GeneratedProtocolMessageType('GetRegisterFacesResponse', (_message.Message,), {
    'DESCRIPTOR': _GETREGISTERFACESRESPONSE,
    '__module__': 'codemao_getregisterfaces_pb2'
    # @@protoc_insertion_point(class_scope:GetRegisterFacesResponse)
})
_sym_db.RegisterMessage(GetRegisterFacesResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
