# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: detectconfig.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import enum_type_wrapper

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='detectconfig.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\036com.ubt.alphamini.facedetector',
    serialized_pb=b'\n\x12\x64\x65tectconfig.proto\"6\n\x06\x43onfig\x12\x1b\n\x05level\x18\x01 \x01(\x0e\x32\x0c.DetectLevel\x12\x0f\n\x07timeout\x18\x02 \x01(\x05*:\n\x0b\x44\x65tectLevel\x12\x07\n\x03LOW\x10\x00\x12\n\n\x06NORMAL\x10\x01\x12\x08\n\x04HIGH\x10\x02\x12\x0c\n\x08ONE_SHOT\x10\x03\x42 \n\x1e\x63om.ubt.alphamini.facedetectorb\x06proto3'
)

_DETECTLEVEL = _descriptor.EnumDescriptor(
    name='DetectLevel',
    full_name='DetectLevel',
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name='LOW', index=0, number=0,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='NORMAL', index=1, number=1,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='HIGH', index=2, number=2,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='ONE_SHOT', index=3, number=3,
            serialized_options=None,
            type=None),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=78,
    serialized_end=136,
)
_sym_db.RegisterEnumDescriptor(_DETECTLEVEL)

DetectLevel = enum_type_wrapper.EnumTypeWrapper(_DETECTLEVEL)
LOW = 0
NORMAL = 1
HIGH = 2
ONE_SHOT = 3

_CONFIG = _descriptor.Descriptor(
    name='Config',
    full_name='Config',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='level', full_name='Config.level', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='timeout', full_name='Config.timeout', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=22,
    serialized_end=76,
)

_CONFIG.fields_by_name['level'].enum_type = _DETECTLEVEL
DESCRIPTOR.message_types_by_name['Config'] = _CONFIG
DESCRIPTOR.enum_types_by_name['DetectLevel'] = _DETECTLEVEL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Config = _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
    'DESCRIPTOR': _CONFIG,
    '__module__': 'detectconfig_pb2'
    # @@protoc_insertion_point(class_scope:Config)
})
_sym_db.RegisterMessage(Config)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
