# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_playexpression.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_playexpression.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x1c\x63odemao_playexpression.proto\"=\n\x15PlayExpressionRequest\x12\x13\n\x0b\x65xpressName\x18\x01 \x01(\t\x12\x0f\n\x07\x64irType\x18\x02 \x01(\x05\"?\n\x16PlayExpressionResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_PLAYEXPRESSIONREQUEST = _descriptor.Descriptor(
    name='PlayExpressionRequest',
    full_name='PlayExpressionRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='expressName', full_name='PlayExpressionRequest.expressName', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='dirType', full_name='PlayExpressionRequest.dirType', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=32,
    serialized_end=93,
)

_PLAYEXPRESSIONRESPONSE = _descriptor.Descriptor(
    name='PlayExpressionResponse',
    full_name='PlayExpressionResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='PlayExpressionResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='PlayExpressionResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=95,
    serialized_end=158,
)

DESCRIPTOR.message_types_by_name['PlayExpressionRequest'] = _PLAYEXPRESSIONREQUEST
DESCRIPTOR.message_types_by_name['PlayExpressionResponse'] = _PLAYEXPRESSIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PlayExpressionRequest = _reflection.GeneratedProtocolMessageType('PlayExpressionRequest', (_message.Message,), {
    'DESCRIPTOR': _PLAYEXPRESSIONREQUEST,
    '__module__': 'codemao_playexpression_pb2'
    # @@protoc_insertion_point(class_scope:PlayExpressionRequest)
})
_sym_db.RegisterMessage(PlayExpressionRequest)

PlayExpressionResponse = _reflection.GeneratedProtocolMessageType('PlayExpressionResponse', (_message.Message,), {
    'DESCRIPTOR': _PLAYEXPRESSIONRESPONSE,
    '__module__': 'codemao_playexpression_pb2'
    # @@protoc_insertion_point(class_scope:PlayExpressionResponse)
})
_sym_db.RegisterMessage(PlayExpressionResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
