# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_getaudiolist.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_getaudiolist.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x1a\x63odemao_getaudiolist.proto\")\n\x13GetAudioListRequest\x12\x12\n\nsearchType\x18\x01 \x01(\x05\"T\n\x14GetAudioListResponse\x12\x15\n\x05\x61udio\x18\x01 \x03(\x0b\x32\x06.Audio\x12\x11\n\tisSuccess\x18\x02 \x01(\x08\x12\x12\n\nresultCode\x18\x03 \x01(\x05\"%\n\x05\x41udio\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06suffix\x18\x02 \x01(\tB\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_GETAUDIOLISTREQUEST = _descriptor.Descriptor(
    name='GetAudioListRequest',
    full_name='GetAudioListRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='searchType', full_name='GetAudioListRequest.searchType', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=30,
    serialized_end=71,
)

_GETAUDIOLISTRESPONSE = _descriptor.Descriptor(
    name='GetAudioListResponse',
    full_name='GetAudioListResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='audio', full_name='GetAudioListResponse.audio', index=0,
            number=1, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='GetAudioListResponse.isSuccess', index=1,
            number=2, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='GetAudioListResponse.resultCode', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=73,
    serialized_end=157,
)

_AUDIO = _descriptor.Descriptor(
    name='Audio',
    full_name='Audio',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='name', full_name='Audio.name', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='suffix', full_name='Audio.suffix', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=159,
    serialized_end=196,
)

_GETAUDIOLISTRESPONSE.fields_by_name['audio'].message_type = _AUDIO
DESCRIPTOR.message_types_by_name['GetAudioListRequest'] = _GETAUDIOLISTREQUEST
DESCRIPTOR.message_types_by_name['GetAudioListResponse'] = _GETAUDIOLISTRESPONSE
DESCRIPTOR.message_types_by_name['Audio'] = _AUDIO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetAudioListRequest = _reflection.GeneratedProtocolMessageType('GetAudioListRequest', (_message.Message,), {
    'DESCRIPTOR': _GETAUDIOLISTREQUEST,
    '__module__': 'codemao_getaudiolist_pb2'
    # @@protoc_insertion_point(class_scope:GetAudioListRequest)
})
_sym_db.RegisterMessage(GetAudioListRequest)

GetAudioListResponse = _reflection.GeneratedProtocolMessageType('GetAudioListResponse', (_message.Message,), {
    'DESCRIPTOR': _GETAUDIOLISTRESPONSE,
    '__module__': 'codemao_getaudiolist_pb2'
    # @@protoc_insertion_point(class_scope:GetAudioListResponse)
})
_sym_db.RegisterMessage(GetAudioListResponse)

Audio = _reflection.GeneratedProtocolMessageType('Audio', (_message.Message,), {
    'DESCRIPTOR': _AUDIO,
    '__module__': 'codemao_getaudiolist_pb2'
    # @@protoc_insertion_point(class_scope:Audio)
})
_sym_db.RegisterMessage(Audio)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
