# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_actioninfo.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_actioninfo.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x18\x63odemao_actioninfo.proto\"M\n\x11\x41\x63tionInfoRequest\x12\x10\n\x08\x61\x63tionId\x18\x01 \x01(\t\x12\x12\n\nactionName\x18\x02 \x01(\t\x12\x12\n\nactionType\x18\x03 \x01(\x05\"N\n\x12\x41\x63tionInfoResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06\x63nName\x18\x02 \x01(\t\x12\x0e\n\x06\x65nName\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_ACTIONINFOREQUEST = _descriptor.Descriptor(
    name='ActionInfoRequest',
    full_name='ActionInfoRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='actionId', full_name='ActionInfoRequest.actionId', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='actionName', full_name='ActionInfoRequest.actionName', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='actionType', full_name='ActionInfoRequest.actionType', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=28,
    serialized_end=105,
)

_ACTIONINFORESPONSE = _descriptor.Descriptor(
    name='ActionInfoResponse',
    full_name='ActionInfoResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='id', full_name='ActionInfoResponse.id', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='cnName', full_name='ActionInfoResponse.cnName', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='enName', full_name='ActionInfoResponse.enName', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='type', full_name='ActionInfoResponse.type', index=3,
            number=4, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=107,
    serialized_end=185,
)

DESCRIPTOR.message_types_by_name['ActionInfoRequest'] = _ACTIONINFOREQUEST
DESCRIPTOR.message_types_by_name['ActionInfoResponse'] = _ACTIONINFORESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ActionInfoRequest = _reflection.GeneratedProtocolMessageType('ActionInfoRequest', (_message.Message,), {
    'DESCRIPTOR': _ACTIONINFOREQUEST,
    '__module__': 'codemao_actioninfo_pb2'
    # @@protoc_insertion_point(class_scope:ActionInfoRequest)
})
_sym_db.RegisterMessage(ActionInfoRequest)

ActionInfoResponse = _reflection.GeneratedProtocolMessageType('ActionInfoResponse', (_message.Message,), {
    'DESCRIPTOR': _ACTIONINFORESPONSE,
    '__module__': 'codemao_actioninfo_pb2'
    # @@protoc_insertion_point(class_scope:ActionInfoResponse)
})
_sym_db.RegisterMessage(ActionInfoResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
