# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_switchtranslatemodel.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_switchtranslatemodel.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\"codemao_switchtranslatemodel.proto\"-\n\x1bSwitchTranslateModelRequest\x12\x0e\n\x06isOpen\x18\x01 \x01(\x08\"E\n\x1cSwitchTranslateModelResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_SWITCHTRANSLATEMODELREQUEST = _descriptor.Descriptor(
    name='SwitchTranslateModelRequest',
    full_name='SwitchTranslateModelRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isOpen', full_name='SwitchTranslateModelRequest.isOpen', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=38,
    serialized_end=83,
)

_SWITCHTRANSLATEMODELRESPONSE = _descriptor.Descriptor(
    name='SwitchTranslateModelResponse',
    full_name='SwitchTranslateModelResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='SwitchTranslateModelResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='SwitchTranslateModelResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=85,
    serialized_end=154,
)

DESCRIPTOR.message_types_by_name['SwitchTranslateModelRequest'] = _SWITCHTRANSLATEMODELREQUEST
DESCRIPTOR.message_types_by_name['SwitchTranslateModelResponse'] = _SWITCHTRANSLATEMODELRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SwitchTranslateModelRequest = _reflection.GeneratedProtocolMessageType('SwitchTranslateModelRequest',
                                                                       (_message.Message,), {
                                                                           'DESCRIPTOR': _SWITCHTRANSLATEMODELREQUEST,
                                                                           '__module__': 'codemao_switchtranslatemodel_pb2'
                                                                           # @@protoc_insertion_point(class_scope:SwitchTranslateModelRequest)
                                                                       })
_sym_db.RegisterMessage(SwitchTranslateModelRequest)

SwitchTranslateModelResponse = _reflection.GeneratedProtocolMessageType('SwitchTranslateModelResponse',
                                                                        (_message.Message,), {
                                                                            'DESCRIPTOR': _SWITCHTRANSLATEMODELRESPONSE,
                                                                            '__module__': 'codemao_switchtranslatemodel_pb2'
                                                                            # @@protoc_insertion_point(class_scope:SwitchTranslateModelResponse)
                                                                        })
_sym_db.RegisterMessage(SwitchTranslateModelResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
