# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: programme_facedetecting.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='programme_facedetecting.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\035com.ubtechinc.alpha.programme',
    serialized_pb=b'\n\x1dprogramme_facedetecting.proto\"\'\n\x14\x46\x61\x63\x65\x44\x65tectingRequest\x12\x0f\n\x07timeout\x18\x01 \x01(\x05\"`\n\x15\x46\x61\x63\x65\x44\x65tectingResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x12\x11\n\tisSuccess\x18\x02 \x01(\x08\x12\x12\n\nresultCode\x18\x03 \x01(\x05\x12\x11\n\tcommandId\x18\x04 \x01(\tB\x1f\n\x1d\x63om.ubtechinc.alpha.programmeb\x06proto3'
)

_FACEDETECTINGREQUEST = _descriptor.Descriptor(
    name='FaceDetectingRequest',
    full_name='FaceDetectingRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='timeout', full_name='FaceDetectingRequest.timeout', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=33,
    serialized_end=72,
)

_FACEDETECTINGRESPONSE = _descriptor.Descriptor(
    name='FaceDetectingResponse',
    full_name='FaceDetectingResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='count', full_name='FaceDetectingResponse.count', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='FaceDetectingResponse.isSuccess', index=1,
            number=2, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='FaceDetectingResponse.resultCode', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='commandId', full_name='FaceDetectingResponse.commandId', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=74,
    serialized_end=170,
)

DESCRIPTOR.message_types_by_name['FaceDetectingRequest'] = _FACEDETECTINGREQUEST
DESCRIPTOR.message_types_by_name['FaceDetectingResponse'] = _FACEDETECTINGRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FaceDetectingRequest = _reflection.GeneratedProtocolMessageType('FaceDetectingRequest', (_message.Message,), {
    'DESCRIPTOR': _FACEDETECTINGREQUEST,
    '__module__': 'programme_facedetecting_pb2'
    # @@protoc_insertion_point(class_scope:FaceDetectingRequest)
})
_sym_db.RegisterMessage(FaceDetectingRequest)

FaceDetectingResponse = _reflection.GeneratedProtocolMessageType('FaceDetectingResponse', (_message.Message,), {
    'DESCRIPTOR': _FACEDETECTINGRESPONSE,
    '__module__': 'programme_facedetecting_pb2'
    # @@protoc_insertion_point(class_scope:FaceDetectingResponse)
})
_sym_db.RegisterMessage(FaceDetectingResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
