# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_playaudio.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from ..pb2 import cloudstorageurls_pb2 as cloudstorageurls__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_playaudio.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\023com.ubtechinc.alpha',
    serialized_pb=b'\n\x17\x63odemao_playaudio.proto\x1a\x16\x63loudstorageurls.proto\"@\n\x10PlayAudioRequest\x12\x1c\n\x05\x63loud\x18\x01 \x01(\x0b\x32\r.CloudStorage\x12\x0e\n\x06volume\x18\x02 \x01(\x02\":\n\x11PlayAudioResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x42\x15\n\x13\x63om.ubtechinc.alphab\x06proto3'
    ,
    dependencies=[cloudstorageurls__pb2.DESCRIPTOR, ])

_PLAYAUDIOREQUEST = _descriptor.Descriptor(
    name='PlayAudioRequest',
    full_name='PlayAudioRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='cloud', full_name='PlayAudioRequest.cloud', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='volume', full_name='PlayAudioRequest.volume', index=1,
            number=2, type=2, cpp_type=6, label=1,
            has_default_value=False, default_value=float(0),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=51,
    serialized_end=115,
)

_PLAYAUDIORESPONSE = _descriptor.Descriptor(
    name='PlayAudioResponse',
    full_name='PlayAudioResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='PlayAudioResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='PlayAudioResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=117,
    serialized_end=175,
)

_PLAYAUDIOREQUEST.fields_by_name['cloud'].message_type = cloudstorageurls__pb2._CLOUDSTORAGE
DESCRIPTOR.message_types_by_name['PlayAudioRequest'] = _PLAYAUDIOREQUEST
DESCRIPTOR.message_types_by_name['PlayAudioResponse'] = _PLAYAUDIORESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PlayAudioRequest = _reflection.GeneratedProtocolMessageType('PlayAudioRequest', (_message.Message,), {
    'DESCRIPTOR': _PLAYAUDIOREQUEST,
    '__module__': 'codemao_playaudio_pb2'
    # @@protoc_insertion_point(class_scope:PlayAudioRequest)
})
_sym_db.RegisterMessage(PlayAudioRequest)

PlayAudioResponse = _reflection.GeneratedProtocolMessageType('PlayAudioResponse', (_message.Message,), {
    'DESCRIPTOR': _PLAYAUDIORESPONSE,
    '__module__': 'codemao_playaudio_pb2'
    # @@protoc_insertion_point(class_scope:PlayAudioResponse)
})
_sym_db.RegisterMessage(PlayAudioResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
