# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cloudwiki.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from ..pb2 import cloudtranslate_pb2 as cloudtranslate__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='cloudwiki.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\023com.ubtechinc.alpha',
    serialized_pb=b'\n\x0f\x63loudwiki.proto\x1a\x14\x63loudtranslate.proto\"R\n\x04WiKi\x12\r\n\x05query\x18\x01 \x01(\t\x12\x0e\n\x06prefix\x18\x02 \x01(\t\x12\x0e\n\x06suffix\x18\x03 \x01(\t\x12\x1b\n\x08platform\x18\x04 \x01(\x0e\x32\t.PlatformB\x15\n\x13\x63om.ubtechinc.alphab\x06proto3'
    ,
    dependencies=[cloudtranslate__pb2.DESCRIPTOR, ])

_WIKI = _descriptor.Descriptor(
    name='WiKi',
    full_name='WiKi',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='query', full_name='WiKi.query', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='prefix', full_name='WiKi.prefix', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='suffix', full_name='WiKi.suffix', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='platform', full_name='WiKi.platform', index=3,
            number=4, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=41,
    serialized_end=123,
)

_WIKI.fields_by_name['platform'].enum_type = cloudtranslate__pb2._PLATFORM
DESCRIPTOR.message_types_by_name['WiKi'] = _WIKI
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WiKi = _reflection.GeneratedProtocolMessageType('WiKi', (_message.Message,), {
    'DESCRIPTOR': _WIKI,
    '__module__': 'cloudwiki_pb2'
    # @@protoc_insertion_point(class_scope:WiKi)
})
_sym_db.RegisterMessage(WiKi)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
