# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pccodemao_disconnection.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='pccodemao_disconnection.proto',
  package='packet',
  syntax='proto3',
  serialized_options=b'\n\034com.ubtrobot.pccodemao.protoB\022DisconnectionProto',
  serialized_pb=b'\n\x1dpccodemao_disconnection.proto\x12\x06packet\"\x16\n\x14\x44isconnectionRequest\"\x17\n\x15\x44isconnectionResponseB2\n\x1c\x63om.ubtrobot.pccodemao.protoB\x12\x44isconnectionProtob\x06proto3'
)




_DISCONNECTIONREQUEST = _descriptor.Descriptor(
  name='DisconnectionRequest',
  full_name='packet.DisconnectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41,
  serialized_end=63,
)


_DISCONNECTIONRESPONSE = _descriptor.Descriptor(
  name='DisconnectionResponse',
  full_name='packet.DisconnectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=88,
)

DESCRIPTOR.message_types_by_name['DisconnectionRequest'] = _DISCONNECTIONREQUEST
DESCRIPTOR.message_types_by_name['DisconnectionResponse'] = _DISCONNECTIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DisconnectionRequest = _reflection.GeneratedProtocolMessageType('DisconnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DISCONNECTIONREQUEST,
  '__module__' : 'pccodemao_disconnection_pb2'
  # @@protoc_insertion_point(class_scope:packet.DisconnectionRequest)
  })
_sym_db.RegisterMessage(DisconnectionRequest)

DisconnectionResponse = _reflection.GeneratedProtocolMessageType('DisconnectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DISCONNECTIONRESPONSE,
  '__module__' : 'pccodemao_disconnection_pb2'
  # @@protoc_insertion_point(class_scope:packet.DisconnectionResponse)
  })
_sym_db.RegisterMessage(DisconnectionResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
